from setuptools import setup

setup(
    name="EGene",
    version="0.1.5",
    author="Ethan Anderson",
    author_email="telan4892@gmail.com",
    url="https://github.com/Elan456/EGene",
    install_requires=['pygame'],
    packages=["egene"],
    license="MIT",
    description="Tool for applying, visualizing, and training neural networks using a genetic algorithm",

    package_data={"": ["images/Icon.png"]}
)